@@ -2,6 +2,7 @@ from flask import Flask, request, jsonify, make_response
 from flask_compress import Compress
 from influxdb import InfluxDBClient, client
 from urllib import parse
+import json
 
 class HomeServices:
 
@@ -9,6 +10,7 @@ class HomeServices:
         self.app = Flask(__name__,  template_folder=template_folder, static_folder=static_folder)
         self.app.add_url_rule('/', 'index', self.index, methods=['GET'])
         self.app.add_url_rule('/alexaintent', 'alexaintent', self.alexa_intent, methods=['GET'])
+        self.app.add_url_rule('/customsensor', 'customsensor', self.custom_sensor, methods=['GET'])
         Compress(self.app)
 
         host = 'pi02'
@@ -22,11 +24,32 @@ class HomeServices:
         return self.app
 
     def run(self):
-        self.app.run()
+        # self.app.run()
+        self.app.run(host='0.0.0.0', port=5000)
 
     def index(self):
         return 'This is the Pi server.'
 
+    def custom_sensor(self):
+        if request.method == 'GET':
+            # Parse GET param
+            sensor = parse.parse_qs(parse.urlparse(request.url).query)['sensor'][0]
+
+            sensor_table = {'jardín': 2, 'salón': 1, 'buhardilla': 3}
+
+            if sensor in sensor_table.keys():
+                query = "SELECT * from DHT22 WHERE sensorid='{}' ORDER BY time DESC LIMIT 1".format(sensor_table[sensor])
+                result_set = self.influx_conn.query(query)
+                point = list(result_set.get_points())[0]
+
+            response = make_response(json.dumps('{{"temp" : {}, "hum" : {} }}'.format(point['temp'], point['humidity'])))
+            response.mimetype = "application/json"
+            response.headers['Pragma'] = 'no-cache'
+            response.headers["Expires"] = 0
+            response.headers['Cache-Control'] = 'no-cache, no-store, must-revalidate'
+            return response
+
+
     def alexa_intent(self):
         if request.method == 'GET':
             # Parse GET param
